sqldiff — django-extensions 0.9.1-beta documentation

### Navigation

- index
- next |
- previous |
- django-extensions 0.9.1-beta documentation »

# sqldiff

synopsis: | Prints the ALTER TABLE statemens for the given appnames.

Django command that scans all models for the given appnames and compares their database schema with the real database tables.

It indicates how columns in the database are different from the SQL that would be generated by Django. This command is not a database migration tool. Though it might certainly be of help during migrations. It’s purpose is to show the current differences as a way to checking or debugging your models compared to the real database tables and columns.

## Example Usage

    # View SQL differences for all installed application
    $ ./manage.py sqldiff -a

    # View SQL differences for all installed application using text instead of SQL
    $ ./manage.py sqldiff -a -t

### Navigation

- index
- next |
- previous |
- django-extensions 0.9.1-beta documentation »